@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: rb-source.h,v 1.8 2003/08/03 07:06:48 cwalters Exp $
+ *  $Id: rb-source.h,v 1.9 2003/08/17 07:34:19 cwalters Exp $
  */
 
 #ifndef __RB_SOURCE_H
@@ -67,8 +67,6 @@ typedef struct
 	RBNodeView *	(*impl_get_node_view)	(RBSource *source);
 	GList *		(*impl_get_extra_views)	(RBSource *source);
 
-	const char *	(*impl_get_description)	(RBSource *source);
-
 	GdkPixbuf *	(*impl_get_pixbuf)	(RBSource *source);
 
 	gboolean	(*impl_can_search)	(RBSource *source);
@@ -118,8 +116,6 @@ RBNodeView *	rb_source_get_node_view		(RBSource *source);
 
 GList *		rb_source_get_extra_views	(RBSource *source);
 
-const char *	rb_source_get_description	(RBSource *source);
-
 GdkPixbuf *	rb_source_get_pixbuf		(RBSource *source);
 
 gboolean	rb_source_can_search		(RBSource *source);
